@@ -1,15 +1,13 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006 Vlad Vasiliev
- * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2006-2008 Vlad Vasiliev
+ * Copyright (C) 2006-2008 Pavel Fialko
  * 	for the code
  *        
- * Copyright (C) Superkaramba's Liquid Weather ++ team
- *	for ALL the artwork (icons)
- *        The maintainer (also the main author I believe)
- *        is Matthew <dmbkiwi@yahoo.com>
- *  http://liquidweather.net/icons.html#iconsets
+ * Copyright (C) 2008 Andrew Zhilin
+ *		      az@pocketpcrussia.com 
+ *	for default icon set (Glance)
  *
  * This software is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public License
@@ -35,10 +33,10 @@ gboolean not_event = FALSE;
 static GSList *event_time_list = NULL;
 /*******************************************************************************/
 gboolean timer_handler(gpointer data){
-    static GSList *list_time_event_temp = NULL;
-    struct event_time *evt;
-    time_t current_time;
-    int check;
+    static	GSList *list_time_event_temp = NULL;
+    struct	event_time *evt;
+    time_t	current_time;
+    int		check;
 #ifndef RELEASE
     char   *temp_string;
     fprintf(stderr, "Begin %s(): \n", __PRETTY_FUNCTION__);
@@ -60,7 +58,7 @@ gboolean timer_handler(gpointer data){
 	if(evt->time <= current_time){
 	    switch(evt->type_event){
 		case DAYTIMEEVENT :
-		#ifdef PC_EMULATOR
+		#ifndef RELEASE
 		    fprintf(stderr,"DAYTIMEEVENT %s\n",ctime(&evt->time));
 		#endif
 		    g_free(evt);
@@ -68,7 +66,7 @@ gboolean timer_handler(gpointer data){
      		    weather_frame_update(FALSE);   
 		break;
 		case DBUSINITEVENT:
-		#ifdef PC_EMULATOR
+		#ifndef RELEASE
 		    fprintf(stderr,"DBUSINITEVENT %s\n",ctime(&evt->time));
 		#endif
 		    g_free(evt);
@@ -91,6 +89,72 @@ gboolean timer_handler(gpointer data){
 		    app->show_update_window = FALSE;
 		    update_weather();
     		break;		    
+		case CHECK_GPS_POSITION:
+		    /* delete periodic update */
+		#ifndef RELEASE
+		    fprintf(stderr,"Delete evt %s\n",ctime(&evt->time));
+		#endif
+		    g_free(evt);
+                    event_time_list = g_slist_remove(event_time_list, event_time_list->data);
+		#ifndef RELEASE
+		    fprintf(stderr,"UPDATE by event\n");
+		#endif
+
+
+
+		#ifdef HILDON
+
+/* This is code for debug GPS
+
+                    double r;
+                    r = (   (double)rand() / ((double)(RAND_MAX)+(double)(1)) );
+                    app->temporary_station_latitude = r*90;
+                    r = (   (double)rand() / ((double)(RAND_MAX)+(double)(1)) );
+                    app->temporary_station_longtitude = r*200;
+                    r = (   (double)rand() / ((double)(RAND_MAX)+(double)(1)) );
+                    if (r<0.5)
+                        app->temporary_station_latitude = app->temporary_station_latitude  * -1;
+                    r = (   (double)rand() / ((double)(RAND_MAX)+(double)(1)) );
+                    if (r<0.5)
+                        app->temporary_station_longtitude = app->temporary_station_longtitude  * -1;
+                
+                    fprintf(file_log,"Event:  Calculate CHECK_GPS_POSITION %f %f %f %f %f\n",
+                                    app->gps_station.latitude,app->gps_station.longtitude,
+                                    app->temporary_station_latitude,app->temporary_station_longtitude,
+                                    calculate_distance(app->gps_station.latitude,app->gps_station.longtitude,
+                                                    app->temporary_station_latitude,app->temporary_station_longtitude));
+		    fflush(file_log);
+*/                    
+                    if (calculate_distance(app->gps_station.latitude,app->gps_station.longtitude,
+                                           app->temporary_station_latitude,app->temporary_station_longtitude)>10){
+								   
+                        get_nearest_station(app->temporary_station_latitude,app->temporary_station_longtitude
+            		                    ,&app->gps_station);		    
+			if ((strlen(app->gps_station.id0) > 0) && (strlen(app->gps_station.name) > 0)){
+		    
+			    app->gps_station.latitude = app->temporary_station_latitude;
+			    app->gps_station.longtitude = app->temporary_station_longtitude;
+			    delete_all_gps_stations();
+                    	    add_station_to_user_list(app->gps_station.name,app->gps_station.id0, TRUE);
+			    if(!app->config->current_station_name && !app->config->current_station_id){
+				app->config->current_station_name = g_strdup(app->gps_station.name);
+				app->config->current_station_id = g_strdup(app->gps_station.id0);		
+			    }
+			    new_config_save(app->config);
+                    	    app->show_update_window = FALSE;
+		    	    update_weather();
+			    weather_frame_update(FALSE);
+			}        
+                    }
+		#endif
+		#ifdef HILDON
+                    /* add periodic gps check */
+                    if (app->gps_station.latitude == 0 && app->gps_station.longtitude == 0)
+                        add_gps_event(1);
+                    else    
+                        add_gps_event(5);
+		#endif
+    		break;		    
   
 		default:
 		case AUTOUPDATE:
@@ -218,7 +282,26 @@ void time_event_add(time_t time_value, short type_event){
     #endif
 }
 /*******************************************************************************/
-/*  Addition the periodic time in the list of events  for weather forecast updating */	  
+/*  Addition the periodic time in the list of events  for weather forecast updating.  
+    Interval is a count of minutes for the next interval */	  
+void add_gps_event(guint interval){
+
+    #ifndef RELEASE
+    fprintf(stderr,"Add in list\n");
+    print_list(NULL, 0);
+    #endif
+
+
+	time_event_add(time(NULL) + interval *60, CHECK_GPS_POSITION); /* Every 'interval' minutes */ 
+
+    #ifndef RELEASE
+    fprintf(stderr,"Item added to list\n");
+    print_list(NULL, 0);
+    #endif
+	
+}
+/*******************************************************************************/
+/*  Addition the periodic time in the list of events  for GPS checking */	  
 void add_periodic_event(time_t last_update){
 
     #ifndef RELEASE
@@ -226,7 +309,7 @@ void add_periodic_event(time_t last_update){
     print_list(NULL, 0);
     #endif
 
-    if(app->config->update_interval > 0)
+/*    if(app->config->gps_station) */
 	time_event_add(last_update + app->config->update_interval * 60, AUTOUPDATE);
 
     #ifndef RELEASE
